function data = h5todata(enc_h5file, rec_h5file)
%H5TODATA converts events from h5 format to matlab data structure
%
% INPUTS
%
% enc_h5file: string - path to encoding hdf5 (power)
% rec_h5file: string - path to encoding hdf5 (power)
%
% OUTPUTS
%
% data: data structure for use with behavioral toolbox

% By James Kragel, 2021
% Distributed under Open Source BSD License

% get the fields from each h5
info = h5info(enc_h5file);
fieldnames = {info.Groups(1).Datasets.Name};
fieldnames(strcmp(fieldnames,'stim_params')) = [];
n_events = info.Groups(1).Datasets(1).Dataspace.Size;
for e = 1:n_events
    for f = 1:length(fieldnames)
        tmp = h5read(enc_h5file, ...
            ['/events/' fieldnames{f}], e, 1);
        
        if iscell(tmp)
            tmp = deblank(char(tmp));
        end
        
        enc_events(e).(fieldnames{f}) = tmp;
    end
end

% get the fields from each h5
info = h5info(rec_h5file);
fieldnames = {info.Groups(1).Datasets.Name};
fieldnames(strcmp(fieldnames,'stim_params')) = [];
n_events = info.Groups(1).Datasets(1).Dataspace.Size;
for e = 1:n_events
    for f = 1:length(fieldnames)
        tmp = h5read(rec_h5file, ...
            ['/events/' fieldnames{f}], e, 1);
        
        if iscell(tmp)
            tmp = deblank(char(tmp));
        end
        rec_events(e).(fieldnames{f}) = tmp;
    end
end

events = [enc_events rec_events];
for k = 1:length(events)
events(k).itemno = events(k).item_num;
end

data = FRdata(events, 'list');

end

