function write_fs_rois()
%WRITE_FS_ROIS writes PM and AT labels for display on freesurfer cortical
%surface
%
% INPUTS
% 
% pow_dir: string - path to directory containing power hdf5s for each
%                   subject
% subject: string - subject identifier
% rois_L: string - cell array of strings, specifying freesurfer label
%                  files in the left hemisphere
% rois_R: string - cell array of strings, specifying freesurfer label
%                  files in the right hemisphere 
% good_elec_flag: logical - flag indicating whether to only include 'good'
%                           electrodes
%
%
% OUTPUTS
%
% none: this function writes .label files to disk (in the current dir)

% By James Kragel, 2021
% Distributed under Open Source BSD License

% read in the annotations in fsaverage space, to write the new ROIs to
% note: these paths need to be updated to point to HCP data
annot_dir = 'path/to/Glasser_et_al_2016_HCP_MMP1.0_RVVG/';
con_dir = 'path/to/Glasser_et_al_2016_HCP_MMP1.0_RVVG/HCP_PhaseTwo/Q1-Q6_RelatedParcellation210/MNINonLinear/Results/rfMRI_REST/';

[vert_L, label_L, clut_L] = read_annotation([annot_dir 'lh.HCP-MMP1.annot']);
[vert_R, label_R, clut_R] = read_annotation([annot_dir 'rh.HCP-MMP1.annot']);

% read in the glasser partial correlation data
left_con_data = ft_read_cifti([con_dir 'rfMRI_REST_Atlas_MSMAll_2_d41_WRN_DeDrift_hp2000_clean_nobias_vn_BC_L.CorticalAreas_dil_Group_group_z_partial.pconn.nii']);
right_con_data = ft_read_cifti([con_dir 'rfMRI_REST_Atlas_MSMAll_2_d41_WRN_DeDrift_hp2000_clean_nobias_vn_BC_R.CorticalAreas_dil_Group_group_z_partial.pconn.nii']);

% and write the new labels
roi_L = {'L_TGd_ROIs', 'L_PGp_ROIs'};
roi_R = {'R_TGd_ROIs', 'R_PGp_ROIs'};

z_thr = 15;

for r = 1:2
    idx = strcmp(left_con_data.label,roi_L{r});
    Z_L = left_con_data.corticalareas_dil_group_group_z_partial(idx,:);
    
    idx = strcmp(right_con_data.label,roi_R{r});
    Z_R = right_con_data.corticalareas_dil_group_group_z_partial(idx,:);
    
    for i = 1:length(Z_L)
        stat_L = nan(size(label_L));
        
        if (Z_L(i) > z_thr)% Z is high enough
            
            stat_L(label_L == clut_L.table(strcmp(clut_L.struct_names, ...
                left_con_data.label{i}),5)) = Z_L(i);
            
            L_label_name = [roi_L{r} '_' left_con_data.label{i} '.label'];
            
            write_label(vert_L, ...
                [], ...
                stat_L, ...
                L_label_name);
        end
        
    end
    
    
    for i = 1:length(Z_R)
        stat_R = nan(size(label_R));
        if Z_R(i) > z_thr
            
            stat_R(label_R == clut_R.table(strcmp(clut_R.struct_names, ...
                right_con_data.label{i}),5)) = Z_R(i);
            
            R_label_name = [roi_R{r} '_' right_con_data.label{i} '.label'];
            
            write_label(vert_R, ...
                [], ...
                stat_R, ...
                R_label_name);
        end
        
    end
end


end

