function tfced = tfce_transform(ts,H,E,C,dh)
%TFCE_TRANSFORM performs threshold free cluster enhancement
%   [tfced] = matlab_tfce_transform(ts,H,E,C,ndh) performs threshold
%   free cluster enhancement on 'observations' as per Smith & Nichols (2009).
%   -- ts the 2D image to be transformed
%   -- H height exponent
%   -- E extent exponent
%   -- C connectivity
%   -- dh size of steps for cluster formation

% set cluster thresholds
threshs = 0:dh:max(ts(:));
threshs = threshs(2:end);
ndh = length(threshs);

% find positive observations (greater than first threshold)
nobs = length(ts(:));

% find connected components
vals = zeros(nobs,1);
cc = arrayfun(@(x) bwconncomp(bsxfun(@ge,ts,x),C), threshs);
for h = 1:ndh
    clustsize = zeros(nobs,1);
    ccc = cc(h);
    voxpercc = cellfun(@numel,ccc.PixelIdxList);
    for c = 1:ccc.NumObjects
        clustsize(ccc.PixelIdxList{c}) = voxpercc(c);
    end
    % calculate transform
    curvals = (clustsize.^E).*(threshs(h)^H);
    vals = vals + curvals;
end
tfced = NaN(size(ts));
tfced(:) = vals.*dh;

end
