function gen_beh_by_catpos_scatter()
%GEN_BEH_BY_CAT plots category space and behavioral results in fig1a, b,
%and c
%
% INPUTS
% 
% none: this function reads intermediate data from the data dir
%
% OUTPUTS
%
% none: this function generates figures for display

% By James Kragel, 2021
% Distributed under Open Source BSD License

% plot the right part of fig 1a, the word2vec space for all words and
% categories
[cat_color_mat, score_cats] = plot_word2vec_space();

load('behav_by_cat.mat');

m_all = nanmean(nanmean(pr,2));
e_all = nansem(nanmean(pr,2));

% alphabetical
[score_cats, i] = sort(score_cats);
cat_color_mat = cat_color_mat(i,:);

[cat_color_mat, x_i] = sortrows(cat_color_mat,[2 3 1],'descend');
score_cats = score_cats(x_i);

m = nanmean(pr);
e = nansem(pr);

m = m(x_i);
e = e(x_i);

semdist = squareform(pdist(cat_color_mat));
semdist(semdist==0)=nan;
semdist = nanmean(semdist)';

fig('FontSize', 16, ...
'Font', 'Arial', ...
'border','on', ...
'units', 'centimeters', ...
'width', 10, ...
'height', 8);

set(gcf, 'Position', [ 6.2971    8.8635   10.9802   16.1660]);

subplot(2,4, [5 8]);

[h, p, c, st] = ttest(pr, m_all);
t = st.tstat(x_i);

fdr = mafdr(p(x_i), 'BHFDR', true);
sig  = find(fdr < .05);
p = p(x_i);

pr_out = pr(:,x_i);

for c = 1:25
    
    he = errorbar(c, m(c), e(c));
    
    this_color = cat_color_mat(c,:);
    
    % plot subjects
    y = pr(:,x_i(c));
    h = plotSpread(y, 'xValues', c);
    
    set(h{1}(1),'SizeData', 48);
    set(h{1}(1),'MarkerFaceColor', this_color);
    set(h{1}(1),'MarkerEdgeColor', this_color);
    
    he.Color = 'k'; %this_color;
    
    if ismember(c, sig)
        he.MarkerFaceColor = 'r';
    else
        he.MarkerFaceColor = [.7 .7 .7];
    end
    he.MarkerSize = 6;
    he.LineWidth = 2;
    uistack(he,'top');

end

hl = line(get(gca,'XLim'), [m_all m_all]);
hl.LineWidth = 2;
hl.LineStyle = '--';
hl.Color = 'k';
uistack(hl, 'bottom');

t = t(sig);

for s = 1:length(sig)
    if t(s) > 0
    h = mysigstar(gca, sig(s), m(sig(s))+.05, p(sig(s)), [1 0 0]);
    else
    h = mysigstar(gca, sig(s), m(sig(s))-.07, p(sig(s)), [1 0 0]);
    end
end

set(gca,'XTick', [], ...
    'box', 'off', ...
    'YLim', [0 1], ...
    'FontSize', 16, ...
    'LineWidth', 2);

xlabel('Category');
ylabel('Recall Probability');

% and by serial position

load('beh_by_cat.mat', 'spc');

spc = squeeze(nanmean(spc,2));
m = nanmean(spc);
e = nanstd(spc)/sqrt(size(spc,1));

m_all = squeeze(nanmean(spc,2));


[h, p, c, st] = ttest(spc, repmat(m_all, 1, 12));
t = st.tstat;

fdr = mafdr(p, 'BHFDR', true);
sig  = find(fdr < .05);

m_all = nanmean(m_all);

subplot(2,4, [1 4]);

for c = 1:12

    he = errorbar(c, m(c), e(c));
    hold on
    
    this_color = [.7 .7 .7];
    
    % plot subjects
    y = spc(:,c);
    h = plotSpread(y, 'xValues', c);
    
    set(h{1}(1),'SizeData', 48);
    set(h{1}(1),'MarkerFaceColor', this_color);
    set(h{1}(1),'MarkerEdgeColor', this_color);
    
    he.Color = 'k'; %this_color;
    if ismember(c, sig)
        he.MarkerFaceColor = 'r';
    else
        he.MarkerFaceColor = [.7 .7 .7];
    end
    he.MarkerSize = 6;
    he.LineWidth = 2;
    uistack(he,'top');

end

hl = line(get(gca,'XLim'), [m_all m_all]);
hl.LineWidth = 2;
hl.LineStyle = '--';
hl.Color = 'k';
uistack(hl, 'bottom');

t = t(sig);

for s = 1:length(sig)
    if t(s) > 0
    h = mysigstar(gca, sig(s), m(sig(s))+.05, p(sig(s)), [1 0 0]);
    else
    h = mysigstar(gca, sig(s), m(sig(s))-.07, p(sig(s)), [1 0 0]);
    end
end

set(gca,'XTick', [], ...
    'box', 'off', ...
    'YLim', [0 1], ...
    'FontSize', 14, ...
    'LineWidth', 2, ...
    'XTick',1:12);

xlabel('Serial Position');
ylabel('Recall Probability');

% Source Data generation -- commented out

% output data, 1b top panel
% xlswrite('SourceData.xlsx', {'Figure1b_top'}, 'Figure1b_top', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure1b_top', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure1b_top', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Serial Position'}, 'Figure1b_top', 'D4');
% xlswrite('SourceData.xlsx', 1:12, 'Figure1b_top', 'D5');
% 
% xlswrite('SourceData.xlsx', spc, 'Figure1b_top', 'D6');
% 
% % output data, 1b bottom panel
% xlswrite('SourceData.xlsx', {'Figure1b_bot'}, 'Figure1b_bot', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure1b_bot', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure1b_bot', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Category'}, 'Figure1b_bot', 'D4');
% xlswrite('SourceData.xlsx', score_cats', 'Figure1b_bot', 'D5');
% 
% xlswrite('SourceData.xlsx', pr_out, 'Figure1b_bot', 'D6');

