function gen_conn_fig()
%GEN_CONN_FIG generates the bottom component of fig2a
%
% INPUTS
% 
% none: this function reads intermediate data from the data dir
%
% OUTPUTS
%
% none: this function generates figures for display

% By James Kragel, 2021
% Distributed under Open Source BSD License

subjects = {};data = {};
load('PMAT_conn');
subs = ident_mscript_subs();
[~, ~, ib] = intersect(subs, subjects);
data = data(ib);

% broken down by individual frequencies
y = nan(length(data),8,5);
for s = 1:length(data)
    if isempty(data{s})
        continue
    end
    y(s,:,1:3) = squeeze(nanmean(data{s},2));
    y(s,:,4) = squeeze(nanmean(data{s}(:,:,1)-data{s}(:,:,3),2));
    y(s,:,5) = squeeze(nanmean(data{s}(:,:,2)-data{s}(:,:,3),2));
end

y_t = reshape(y,size(y,1),[]);
b_s = any(isnan(y_t),2);
y(b_s,:,:)=nan;

m = squeeze(nanmean(y));
e = squeeze(nansem(y)); 

tmp = squeeze(y(:,:,4));
tmp(any(isnan(tmp),2),:)=[];
[p_at_pos, p_at_neg] = perm_ttest_onesample(tmp',2,100000);

tmp = squeeze(y(:,:,5));
tmp(any(isnan(tmp),2),:)=[];
[p_pm_pos, p_pm_neg] = perm_ttest_onesample(tmp',2,100000);

figure;
set(gcf,'Position',[42   663   908   307]);
subplot(1,2,2);
hold on
for f = 1:8

    y_tmp = squeeze(y(:,f,4));
    h = plotSpread(y_tmp, 'xValues', f);
    
    set(h{1}(1),'MarkerFaceColor', [112 191 65]/255);
    set(h{1}(1),'MarkerEdgeColor', [112 191 65]/255);
    
    hl = errorbar(f,m(f,4), e(f,4),'-');
    hl.LineWidth = 2; hl.Color = 'k';
    hs = mysigstar(gca, f, .3, p_at_pos(f), 'r'); %m(f,4)+e(f,4)+.01
    hs.FontSize = 14;
        
end

hl = refline(0);
hl.Color = 'k'; hl.LineStyle = '--';
uistack(hl,'bottom');

set(gca,'XLim',[0 9],'YLim',[-.3 .4],'FontSize',16);
set(gca,'XTick',1:8,...
    'XTickLabel', []);
ylabel('\Delta Connectivity')

set(gca, 'box', 'off', ...
         'LineWidth', 2, ...
         'XTickLabel', round(logspace(log10(3),log10(180),8)), ...
         'XTickLabelRotation', 90);

xlabel('Frequency (Hz)');

subplot(1,2,1);
hold on
for f = 1:8
    y_tmp = squeeze(y(:,f,5));
    h = plotSpread(y_tmp, 'xValues', f);
    
    set(h{1}(1),'MarkerFaceColor', [119 63 155]/255);
    set(h{1}(1),'MarkerEdgeColor', [119 63 155]/255);
    
    hl = errorbar(f,m(f,5), e(f,5),'-');
    hl.LineWidth = 2; hl.Color = 'k';
    hs = mysigstar(gca, f, .3, p_pm_pos(f), 'r'); %m(f,4)+e(f,4)+.01
    hs.FontSize = 14;

end

set(gca, 'XLim', [0 9], ...
         'YLim', [-.3 .4], ...
         'FontSize', 16,...
         'XTick', 1:8,...
         'XTickLabel', round(logspace(log10(3),log10(180),8)),...
         'XTickLabelRotation', 90, ...
         'box', 'off', ...
         'LineWidth', 2);

ylabel('\Delta Connectivity')
xlabel('Frequency (Hz)');

hl = refline(0);
hl.Color = 'k'; hl.LineStyle = '--';
uistack(hl,'bottom');

% Source Data generation -- commented out

% output data, 2a bottom left panel
% xlswrite('SourceData.xlsx', {'Figure2a_bl'}, 'Figure2a_bl', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure2a_bl', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure2a_bl', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Frequency'}, 'Figure2a_bl', 'D4');
% xlswrite('SourceData.xlsx', [round(logspace(log10(3),log10(180),8))], 'Figure2a_bl', 'D5');
% 
% xlswrite('SourceData.xlsx', squeeze(y(:,:,5)), 'Figure2a_bl', 'D6');
% 
% % output data, 2a bottom right panel
% xlswrite('SourceData.xlsx', {'Figure2a_br'}, 'Figure2a_br', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure2a_br', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure2a_br', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Frequency'}, 'Figure2a_br', 'D4');
% xlswrite('SourceData.xlsx', [round(logspace(log10(3),log10(180),8))], 'Figure2a_bl', 'D5');
% 
% xlswrite('SourceData.xlsx', squeeze(y(:,:,4)), 'Figure2a_br', 'D6');

end

