function gen_encode_figs()
%GEN_ENCODE_FIGS generates encoding accuracy for fig2c and d
%
% INPUTS
% 
% none: this function reads intermediate data from the data dir
%
% OUTPUTS
%
% none: this function generates figures for display

% By James Kragel, 2021
% Distributed under Open Source BSD License
      
colors = [102 51 153;
          102 204 51;
          0 0 0]/255;
      
load('enc_auc', 'Ps', 'As', 'Pc', 'Ac');

%% serial position decoding
figure;

h = plotSpread([Ps; As]');

set(gca,'YLim', [0.4 1], ...
        'Color', 'none', ...
        'XColor', 'none');

set(h{1}(1),'SizeData',48);
set(h{1}(1),'MarkerFaceColor', colors(1,:));
set(h{1}(1),'MarkerEdgeColor', colors(1,:));

set(h{1}(2),'SizeData',48);
set(h{1}(2),'MarkerFaceColor', colors(2,:));
set(h{1}(2),'MarkerEdgeColor', colors(2,:));


x = [1 2];
y = nanmean([Ps; As]');
e = 1.96*nanstd([Ps; As]')./sqrt(length(Ps));

he = errorbar(x, y, e);
he.LineStyle = 'none'; he.Color = 'k'; he.LineWidth = 2;

% add stats
[p,h,stats] = signrank(Ps, .5);
hs = mysigstar(gca, 1, .85, p, 'r');    

[p,h,stats] = signrank(As, .5);
hs = mysigstar(gca, 2, .85, p, 'r');    

[p,h,stats] = signrank(Ps,As);

if p<.05
   hl = plot([1 2], [.9 .9], 'k-');
   hl.LineWidth = 2;
   
   hl = plot([1 1], [.89 .9], 'k-');
   hl.LineWidth = 2;
   hl = plot([2 2], [.89 .9], 'k-');
   hl.LineWidth = 2;
   
   hs = mysigstar(gca, 1.5, .915, p, 'r');    
end

set(gca,'FontSize', 16, ...
        'LineWidth', 2);
    
ylabel({'Decoding (AUC)'});
% set(gcf,'Position', [2167 478 218 177]);


hl = line([0 3], [.5 .5]);
hl.Color = 'k';
hl.LineStyle = '--';
hl.LineWidth = 2;
uistack(hl,'bottom');

set(gcf,'Position',[88   742   362   249]);

%% category decoding
figure;

h = plotSpread([Pc; Ac]');

set(gca,'YLim', [0.4 0.8], ...
        'Color', 'none', ...
        'XColor', 'none');

set(h{1}(1),'SizeData',48);
set(h{1}(1),'MarkerFaceColor', colors(1,:));
set(h{1}(1),'MarkerEdgeColor', colors(1,:));

set(h{1}(2),'SizeData',48);
set(h{1}(2),'MarkerFaceColor', colors(2,:));
set(h{1}(2),'MarkerEdgeColor', colors(2,:));

x = [1 2];
y = nanmean([Pc; Ac]');
e = 1.96*nanstd([Pc; Ac]')./sqrt(length(Pc));

he = errorbar(x, y, e);
he.LineStyle = 'none'; he.Color = 'k'; he.LineWidth = 2;

% add stats
[p,h,stats] = signrank(Pc, .5);
hs = mysigstar(gca, 1, .7, p, 'r');    

[p,h,stats] = signrank(Ac, .5);
hs = mysigstar(gca, 2, .7, p, 'r');    

[p,h,stats] = signrank(Pc,Ac);

if p<.05
   hl = plot([1 2], [.8 .8], 'k-');
   hl.LineWidth = 2;
   
   hl = plot([1 1], [.695 .8], 'k-');
   hl.LineWidth = 2;
   hl = plot([2 2], [.695 .8], 'k-');
   hl.LineWidth = 2;
   
   hs = mysigstar(gca, 1.5, .925, p, 'r');    
end


set(gca,'FontSize', 16, ...
        'LineWidth', 2);
    
ylabel({'Decoding (AUC)'});
% set(gcf,'Position', [2167 478 218 177]);

hl = line([0 3], [.5 .5]);
hl.Color = 'k';
hl.LineStyle = '--';
hl.LineWidth = 2;
uistack(hl,'bottom');

set(gcf,'Position',[88   742   362   249]);

% Source Data generation -- commented out

% output data, 2c
% xlswrite('SourceData.xlsx', {'Figure2c'}, 'Figure2c', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure2c', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure2c', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Network'}, 'Figure2c', 'D4');
% xlswrite('SourceData.xlsx', {'PM','AT'}, 'Figure2c', 'D5');
% 
% xlswrite('SourceData.xlsx', [Pc; Ac]', 'Figure2c', 'D6');
% 
% 
% % output data, 2c
% xlswrite('SourceData.xlsx', {'Figure2d'}, 'Figure2d', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure2d', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure2d', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Network'}, 'Figure2d', 'D4');
% xlswrite('SourceData.xlsx', {'PM','AT'}, 'Figure2d', 'D5');
% 
% xlswrite('SourceData.xlsx', [Ps; As]', 'Figure2d', 'D6');


end

