function gen_factor_scores()
%GEN_FACTOR_SCORES generates figures 1e
%
% INPUTS
% 
% none: this function reads intermediate data from the data dir
%
% OUTPUTS
%
% none: this function generates figures for display

% By James Kragel, 2021
% Distributed under Open Source BSD License

load('behav.mat','t','c');

% Figure 1b
h = gen_dist_graph(t,c);

end

function h = gen_dist_graph(t,c)

% Bar graph with points for individual subjects, temporal clustering (t), and category clustering (c)

figure;
% plot the spreads to overlay mean, SEM

h = plotSpread([c; t]', 'Xvalues', [2.5 3.5], 'xyOri', 'flipped');

set(h{1}(1),'SizeData',64);
set(h{1}(2),'SizeData',64);

set(h{1}(1),'MarkerFaceColor', [1 0 0]);
set(h{1}(1),'MarkerEdgeColor', [1 0 0]);

set(h{1}(2),'MarkerFaceColor', [0 0 1]);
set(h{1}(2),'MarkerEdgeColor', [0 0 1]);

hold on;

% plot mean +/- SEM
x = [2.5 3.5];
y = nanmean([c; t]');
e = 1.96*nanstd([c; t]')./sqrt(length(t));

he = errorbar(y(1),x(1),e(1),'horizontal');
he.LineStyle = 'none'; he.Color = 'k'; he.LineWidth = 2;

he = errorbar(y(2),x(2),e(2),'horizontal');
he.LineStyle = 'none'; he.Color = 'k'; he.LineWidth = 2;
he.Marker = 'none';

set(gca,'YLim',[2 4], 'YTick', [2.5 3.5], 'XLim',[0 1], ...
        'LineWidth', 2, 'Ycolor', 'none', 'Color', 'none');

set(gca,'FontSize', 16, ...
        'YTickLabel', {'Temporal', 'Categorical'},...
        'LineWidth', 2);
    
xlabel('Factor Score');

hl = line([.5 .5], get(gca,'Ylim'));
hl.Color = 'k';
hl.LineStyle = '--';
hl.LineWidth = 2;

hleg = legend([h{1}(2), h{1}(1)], {'Temporal', 'Categorical'});
hleg.Box = 'off'; hleg.Location = 'NorthWest';

set(gcf,'Position', [75   710   560   216]);

% sig for temporal
[~, p, ~, ~] = ttest(t,.5);
mysigstar(gca, y(2), 3.9, p, 'k');

% sig for categorical
[~, p, ~, ~] = ttest(c,.5);
mysigstar(gca, y(1), 2.9, p, 'k');

% Source Data generation -- commented out
% 
% xlswrite('SourceData.xlsx', {'Figure1f'}, 'Figure1f', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure1f', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure1f', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Factor Score'}, 'Figure1f', 'D4');
% xlswrite('SourceData.xlsx', {'Temporal','Categorical'}, 'Figure1f', 'D5');
% 
% xlswrite('SourceData.xlsx', [t; c]', 'Figure1f', 'D6');

end
