function gen_reins_corr_figs()
%GEN_REINS_CORR_FIGS generates figure 3c
%
% INPUTS
% 
% none: this function reads intermediate data from the data dir
%
% OUTPUTS
%
% none: this function generates figures for display

% By James Kragel, 2021
% Distributed under Open Source BSD License

load('behav.mat','t','c','p');
load('reins_auc', 'sp', 'sa', 'cp', 'ca');

% Figure 3c
h2 = gen_ts_corr(t, c, sp, sa, cp, ca);

end

function hbl = gen_ts_corr(t, c, sp, sa, cp, ca)

for i = 1:40
    
[r_sp(i),pval_sp(i)] = corr(t',sp(i,:)' ,'rows','complete');
[r_sa(i),pval_sa(i)] = corr(t',sa(i,:)' ,'rows','complete');

[r_cp(i),pval_cp(i)] = corr(c',cp(i,:)' ,'rows','complete');
[r_ca(i),pval_ca(i)] = corr(c',ca(i,:)' ,'rows','complete');

[r_sd(i),pval_sd(i)] = corr(t',sp(i,:)'-sa(i,:)' ,'rows','complete');
[r_cd(i),pval_cd(i)] = corr(c',cp(i,:)'-ca(i,:)' ,'rows','complete');

end

tp = 16:21;

x1 = nanmean(sp(tp,:)) - nanmean(sa(tp,:));
x2 = nanmean(cp(tp,:)) - nanmean(ca(tp,:));

y1 = t;
y2 = c;

figure;
mdl = fitlm(x1,y1,'y ~ x1');
x = -.1:.001:.15;
[ypred,yci] = predict(mdl,x');
e = abs(yci(:,1)-ypred);
[hbl, hbp] = boundedline(x, ypred, e);
hold on
hp = plot(x1,y1,'ko');
set(gca,'XLim',[-.1 .15], 'YLim', [.4 1],'Box','off','LineWidth',2,...
    'FontSize', 16);
axis square
hp.MarkerEdgeColor = [.7 .7 .7];
hp.MarkerFaceColor = [.7 .7 .7];
uistack(hp,'bottom');
hbl.Color = 'r'; hbl.LineWidth = 2;
hbp.FaceColor = 'r';
hbp.FaceAlpha = .2;
hx = xlabel('Network Reinstatement (\DeltaAUC)');
hy = ylabel('Temporal Organization (TF)');

[rho, pval] = corr(x1',y1');
res_str = sprintf('r = %0.2f\np = %0.3f', rho, pval);
ht = text(-.05,.9,res_str);ht.FontSize = 14;

figure;
mdl = fitlm(x2,y2,'y ~ x1');
x = -.15:.001:.1;
[ypred,yci] = predict(mdl,x');
e = abs(yci(:,1)-ypred);
[hbl, hbp] = boundedline(x, ypred, e);
hold on
hp = plot(x2,y2,'ko');
set(gca,'XLim',[-.15 .1], 'YLim', [.4 1],'Box','off','LineWidth',2,...
    'FontSize', 16);
axis square
hp.MarkerEdgeColor = [.7 .7 .7];
hp.MarkerFaceColor = [.7 .7 .7];
uistack(hp,'bottom');
hbl.Color = 'r'; hbl.LineWidth = 2;
hbp.FaceColor = 'r';
hbp.FaceAlpha = .2;
hx = xlabel('Network Reinstatement (\DeltaAUC)');
hy = ylabel('Categorical Organization (CF)');

[rho, pval] = corr(x2',y2');
res_str = sprintf('r = %0.2f\np = %0.3f', rho, pval);
ht = text(-.05,.5,res_str);ht.FontSize = 14;

% Source Data generation -- commented out

% % output data, 3c top panel
% xlswrite('SourceData.xlsx', {'Figure3c_t'}, 'Figure3c_t', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure3c_t', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure3c_t', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Temporal Factor'}, 'Figure3c_t', 'D5');
% xlswrite('SourceData.xlsx', {'Network Reinstatement (PM - AT'}, 'Figure3c_t', 'E5');
% 
% xlswrite('SourceData.xlsx', [y1; x1]', 'Figure3c_t', 'D6');
% 
% % output data, 3c, bottom
% 
% xlswrite('SourceData.xlsx', {'Figure3c_b'}, 'Figure3c_b', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Subject'}, 'Figure3c_b', 'B6');
% xlswrite('SourceData.xlsx', [1:69]', 'Figure3c_b', 'C6:C74');
% 
% xlswrite('SourceData.xlsx', {'Category Factor'}, 'Figure3c_b', 'D5');
% xlswrite('SourceData.xlsx', {'Network Reinstatement (PM - AT'}, 'Figure3c_b', 'E5');
% 
% xlswrite('SourceData.xlsx', [y2; x2]', 'Figure3c_b', 'D6');


end

