function [cat_color_mat, score_cats] = plot_word2vec_space()
%PLOT_WORD2VEC_SPACE
%
% INPUTS
% 
% none: this function reads intermediate data from the data dir
%
% OUTPUTS
%
% none: this function generates figures for display

% By James Kragel, 2021
% Distributed under Open Source BSD License

% get word2vec for the words
words = textread('CatFR1_wordpool.txt','%s');
word_vecs = h5read('CatFR1_vecs.h5','/vecs');

load('cat_item_vecs','category','item','vecs');

for k = 1:length(words)
    cats{k} = category{find(strcmp(words{k},item),1,'first')};
end

[cat_vecs, ia, ib] = unique(vecs,'rows');
score_cats = category(ia);

%% pca version

[coeff, score, latent, tsquared, explained] = pca(word_vecs);


cat_score = bsxfun(@minus,cat_vecs,nanmean(cat_vecs))*coeff; 
cat_score = cat_score(:,1:3);

for c = 1:size(cat_score,2)
    cat_color_mat(:,c) = (cat_score(:,c)+.35)/max(cat_score(:,c)+.35);
end

cat_color_mat(cat_color_mat<0)=0;
cat_color_mat(cat_color_mat>1)=1;

figure;hc = scatter3(cat_score(:,1),cat_score(:,2),cat_score(:,3),60,cat_color_mat);
hc.MarkerFaceColor = hc.MarkerEdgeColor;
set(gca, 'Xdir', 'reverse')
xlabel('D1'); ylabel('D2'); zlabel('D3');

for c = 1:length(cats)
    word_color_mat(c,:) = cat_color_mat(find(strcmp(cats{c},score_cats),1,'first'),:); % + [.2 .2 .2]
end

word_color_mat(word_color_mat > 1)=1;

hold on
hw = scatter3(score(:,1),score(:,2),score(:,3),30,word_color_mat);
hw.MarkerFaceColor = hw.MarkerEdgeColor;

hold on;
cat_score = double(cat_score);
for ii = 1:numel(cat_score(:,1))
    ht(ii) = text(cat_score(ii,1),...
        cat_score(ii,2),...
        cat_score(ii,3),...
        score_cats(ii),'FontSize',16);
    
    ht(ii).Color = cat_color_mat(ii,:);
    ht(ii).FontWeight = 'bold';
end

set(gca,'GridLineStyle','none','Visible','off');

% set camera view
view(0,0);
camroll(90);
set(gca,'XDir','reverse');
set(gca,'ZLim',[-.6 .6]);
set(gca,'XLim',[-.6 .6]);
set(gca,'YLim',[-.6 .6]);
set(gca,'Visible','off');


fig('FontSize', 16, ...
'Font', 'Arial', ...
'border','on', ...
'units', 'centimeters', ...
'width', 10, ...
'height', 8);

set(gcf,'Position',[7.5142   13.3879   19.0235    7.9904]);

subplot(1,3,2);


% Define a six row by four column matrix to define the six cube faces
fm = [1 2 6 5;
      2 3 7 6;
      3 4 8 7;
      4 1 5 8;
      1 2 3 4;
      5 6 7 8];

% Define an eight row by three column matrix to define the vertices at which the faces meet
vm = [0 0 0;
      1 0 0;
      1 1 0;
      0 1 0;
      0 0 1;
      1 0 1;
      1 1 1;
      0 1 1];

% RGB colors for each vertex
cm = [0 0 0;
      0 1 0;
      1 1 0;
      1 0 0;
      0 0 1;
      0 1 1;
      1 1 1;
      1 0 1];

% Plot the cube - gives each face a different color and creates the cube at a convenient viewing angle
patch('Vertices',vm,'Faces',fm,'FaceVertexCData',cm,'FaceColor','interp');
view(120,30);

% Plot axes
axis equal;
axis off;
d1 = 1.25;

% % Label axes
d2 = 0.1;
% % text([0 1 0],[1 -d2 -d2],[-d2 0 1],'255','FontSize',11,'HorizontalAlignment','center');
ht = text([0 d1 0],[d1 d2 d2],[d2 0 d1],{'PC1','PC2','PC3'},'FontSize',16);

% Source Data generation -- commented out

% xlswrite('SourceData.xlsx', {'Figure1d'}, 'Figure1d', 'A3'); 
% 
% xlswrite('SourceData.xlsx', {'Category'}, 'Figure1d', 'B6');
% xlswrite('SourceData.xlsx', score_cats, 'Figure1d', 'C6:C30');
% 
% xlswrite('SourceData.xlsx', {'PC Score'}, 'Figure1d', 'D4');
% xlswrite('SourceData.xlsx', {'Dim1','Dim2','Dim3'}, 'Figure1d', 'D5');
% 
% xlswrite('SourceData.xlsx', cat_score, 'Figure1d', 'D6');


end

