function tal = get_tal_from_json(json_file, good_elec_flag, chantype, subj)
%GET_TAL_FROM_JSON loads electrode information from json file (called a tal
% structure for historical reasons)
%
% INPUTS
%
% json_file: string - points to the json file (pairs.json or contacts.json)
%                     to load
%
% good_elec_flag: logical - boolean flag specifying whether to only return
%                           'good' contacts
%
% chantype: string - specifies whether you want to load channel or pair
%                    information
%
% subj: string - subject identifier
%
% OUTPUTS
%
% data: data structure for use with behavioral toolbox

% By James Kragel, 2021
% Distributed under Open Source BSD License

% folder with pairs.json and electrode_categories.txt
loc_dir = '../../data/localizations/'; 

json_struct = loadjson(json_file);

fns = fieldnames(json_struct);
fns(strcmp(fns,'version')) = [];

% grab subj

chan_flag = ~isempty(chantype);

if chan_flag
subj = fns{1};
json_struct = json_struct.(fns{1});
end

% grab pairs
if chan_flag
    json_struct = json_struct.(chantype);
end

if chan_flag
    chan_names = fieldnames(json_struct);
else
    chan_names = fieldnames(json_struct.label);
end

for c = 1:length(chan_names)
    if chan_flag
    tal(c).subject = subj;
    end
    
    if chan_flag
        try
            tal(c).channel = [json_struct.(chan_names{c}).channel_1 json_struct.(chan_names{c}).channel_2];
        catch
            tal(c).channel = json_struct.(chan_names{c}).channel;
        end
    else
        tal(c).channel = [json_struct.contact_1.(chan_names{c}) json_struct.contact_2.(chan_names{c})];
    end
    
    if chan_flag
        tal(c).tagName = json_struct.(chan_names{c}).code;
    else
        tal(c).tagName = json_struct.label.(chan_names{c});
    end
    
    if chan_flag
    try
        tal(c).eType = {json_struct.(chan_names{c}).type_1 json_struct.(chan_names{c}).type_2};
    catch
        tal(c).eType = json_struct.(chan_names{c}).type;
    end
    else
        tal(c).eType = {json_struct.type_1.(chan_names{c}) json_struct.type_2.(chan_names{c})};
    end
    
    if chan_flag
    try
        tal(c).xyz_indiv = [json_struct.(chan_names{c}).atlases.ind_0x2E_corrected.x ...
            json_struct.(chan_names{c}).atlases.ind_0x2E_corrected.y ...
            json_struct.(chan_names{c}).atlases.ind_0x2E_corrected.z];
    catch
        try
            tal(c).xyz_indiv = [json_struct.(chan_names{c}).atlases.ind_0x2E_dural.x ...
                json_struct.(chan_names{c}).atlases.ind_0x2E_dural.y ...
                json_struct.(chan_names{c}).atlases.ind_0x2E_dural.z];
        catch
            tal(c).xyz_indiv = [nan nan nan];
        end
    end
    else
        try
        tal(c).xyz_indiv = [json_struct.ind_0x2E_corrected_0x2E_x.(chan_names{c}) ...
            json_struct.ind_0x2E_corrected_0x2E_y.(chan_names{c}) ...
            json_struct.ind_0x2E_corrected_0x2E_z.(chan_names{c})];
        catch
            tal(c).xyz_indiv = [json_struct.ind_0x2E_dural_0x2E_x.(chan_names{c}) ...
                json_struct.ind_0x2E_dural_0x2E_y.(chan_names{c}) ...
                json_struct.ind_0x2E_dural_0x2E_z.(chan_names{c})];
        end
    end
    
    if chan_flag
        try
            tal(c).xyz_avg = [json_struct.(chan_names{c}).atlases.avg_0x2E_corrected.x ...
                json_struct.(chan_names{c}).atlases.avg_0x2E_corrected.y ...
                json_struct.(chan_names{c}).atlases.avg_0x2E_corrected.z];
        catch
            try
                tal(c).xyz_avg = [json_struct.(chan_names{c}).atlases.avg_0x2E_dural.x ...
                    json_struct.(chan_names{c}).atlases.avg_0x2E_dural.y ...
                    json_struct.(chan_names{c}).atlases.avg_0x2E_dural.z];
            catch
                tal(c).xyz_avg = [nan nan nan];
            end
        end
    else
        try
        tal(c).xyz_avg = [json_struct.avg_0x2E_corrected_0x2E_x.(chan_names{c}) ...
            json_struct.avg_0x2E_corrected_0x2E_y.(chan_names{c}) ...
            json_struct.avg_0x2E_corrected_0x2E_z.(chan_names{c})];
        catch
            tal(c).xyz_avg = [json_struct.avg_0x2E_dural_0x2E_x.(chan_names{c}) ...
                json_struct.avg_0x2E_dural_0x2E_y.(chan_names{c}) ...
                json_struct.avg_0x2E_dural_0x2E_z.(chan_names{c})];
        end
    end
    
    if chan_flag
    try
    tal(c).xyz_mni = [json_struct.(chan_names{c}).atlases.mni.x ...
        json_struct.(chan_names{c}).atlases.mni.y ...
        json_struct.(chan_names{c}).atlases.mni.z];
    catch
    tal(c).xyz_mni = [nan nan nan];    
    end
    else
        try
                tal(c).xyz_mni = [json_struct.mni_0x2E_x.(chan_names{c}) ...
            json_struct.mni_0x2E_y.(chan_names{c}) ...
            json_struct.mni_0x2E_z.(chan_names{c})];
        catch
                        tal(c).xyz_mni = [json_struct.tal_0x2E_x.(chan_names{c}) ...
            json_struct.tal_0x2E_y.(chan_names{c}) ...
            json_struct.tal_0x2E_z.(chan_names{c})];    
        end
    end
    
    if chan_flag
    try
        tal(c).region = [json_struct.(chan_names{c}).atlases.dk.region];
    catch
        try
        tal(c).region = [json_struct.(chan_names{c}).atlases.ind.region];
        catch
            tal(c).region = '';
        end
    end
    else
        try
        tal(c).region = [json_struct.avg_0x2E_corrected_0x2E_region.(chan_names{c})];
        catch
        tal(c).region = [json_struct.avg_0x2E_dural_0x2E_region.(chan_names{c})];    
        end
    end
    
    if chan_flag
    try
        tal(c).locTag = [json_struct.(chan_names{c}).atlases.stein.region];
    catch
        try
            tal(c).locTag = [json_struct.(chan_names{c}).atlases.das.region];
        catch
            tal(c).locTag = [];
        end
    end
    else
        try
       tal(c).locTag = [json_struct.stein_0x2E_region.(chan_names{c})];
        catch
            tal(c).locTag = '';
        end
    end
    
end

ts = strfind(subj,'_');
if ~isempty(ts)
    ts = ts(1);
    subj = subj(1:ts-1);
end

if exist([loc_dir subj '\electrode_categories.txt'],'file') && good_elec_flag
    % remove electrode_categories.txt
    fid = fopen([loc_dir subj '\electrode_categories.txt']);
    a = textscan(fid,'%s','Delimiter','\n');
    a = a{1}; fclose(fid);
    electrodeCategories = false(size(tal));
    for iline = 1:length(a)
        if ~strcmp(a{iline},'-')
            electrodeCategories = electrodeCategories | ~cellfun(@isempty,strfind({tal.tagName},a{iline}));
        end
    end
    for e = 1:length(tal)
        tal(e).bad_elec = electrodeCategories(e);
    end
end

end

