function [wPM_mask, wAT_mask, between_mask, mask] = make_masks(AT, PM, ...
    dist, bp_shared)
%MAKE_MASKS helper function to make logical masks to select combinations of
% bipolar pairs for connectivity analysis
%
% INPUTS
%
% AT: logical - boolean indicating whether a contact is within AT network
% PM: logical - boolean indicating whether a contact is within PM network
% dist: double - array specifying distance between contacts
% bp_shared: logical - array specifying whether the combination of bipolar
% pairs share a single individual contact (e.g., A1-A2, A2-A3)
%
% OUTPUTS
%
% data: data structure for use with behavioral toolbox

% By James Kragel, 2021
% Distributed under Open Source BSD License

% bipolar mask
mask = tril(ones(size(dist)),-1);
mask(bp_shared) = false;

% within PM
wPM_mask = false(size(dist));
for x = 1:length(PM)
    for y = 1:length(PM)
        if PM(x) && PM(y)
            wPM_mask(x,y) = true;
        end
    end
end

% compute actual dists for PM, AT
wAT_mask = false(size(dist));
for x = 1:length(AT)
    for y = 1:length(AT)
        if AT(x) && AT(y)
            wAT_mask(x,y) = true;
        end
    end
end

between_mask = false(size(dist));
for x = 1:length(AT)
    for y = 1:length(AT)
        if (AT(x) && PM(y)) || (AT(y) && PM(x))
            between_mask(x,y) = true;
        end
    end
end


end

